/*
Converts YUV to RGB floating point
*/

#include <stdio.h>
#include <stdlib.h>

#define	TRUE		1
#define	FALSE		0

/* color space conversion coefficients
 * for YCbCr -> RGB mapping
 *
 * entries are {crv,cbu,cgu,cgv}
 *
 * crv=(219/224)*(1-cr)/0.5
 * cbu=(219/224)*(1-cb)/0.5
 * cgu=(219/224)*(cb/cg)*(1-cb)/0.5
 * cgv=(219/224)*(cr/cg)*(1-cr)/0.5
 *
 * where Y=cr*R+cg*G+cb*B (cr+cg+cb=1)
 */

/* ITU-R BT709-5 (2002) coefficients */
/* cg = 0.7152 */
/* cb = 0.0722 */
/* cr = 0.2126 */

int main(int argc, char **argv)
{
	int		y, cr, cb;
	double	r, g, b;

	if (argc != 4) {
		fprintf(stderr, "usage: yuvtorgbcalc <Y> <Cb> <Cr>\n");
		exit(-1);
	}

	y = atoi(argv[1]);
	cb = atoi(argv[2]);
	cr = atoi(argv[3]);

	r = (double)y + 1.5396482142857 * (double)(cr - 128);
	g = (double)y - 0.4576750704098 * (double)(cr - 128) - 0.18314292755273 * (double)(cb - 128);
	b = (double)y + 1.814180357142857 * (double)(cb - 128);

	printf("R = %f, G = %f, B = %f\n", r, g, b);

	return 0;
}
